Termy : Your Terminal Assistant
=========
A lightweight terminal assistant to give a natural language interface to your terminal commands


How to install
============
Thanks to pip! its as simple as :

```
pip install --upgrade pip
pip install termy
```


Install Directly from Source
=============
Clone this repository. Open the folder and execute the following commands. 
```
pip install --upgrade pip
pip install -e .
```

How to Use
=============

